@@ -17,7 +17,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-#coding=utf-8
+# coding=utf-8
 
 """
 Acs ERROR CODE module.
@@ -31,3 +31,8 @@ SDK_INVALID_REGION_ID = 'SDK.InvalidRegionId'
 SDK_SERVER_UNREACHABLE = 'SDK.ServerUnreachable'
 SDK_INVALID_REQUEST = 'SDK.InvalidRequest'
 SDK_MISSING_ENDPOINTS_FILER = 'SDK.MissingEndpointsFiler'
+SDK_UNKNOWN_SERVER_ERROR = 'SDK.UnknownServerError'
+SDK_INVALID_CREDENTIAL = 'SDK.InvalidCredential'
+SDK_INVALID_SESSION_EXPIRATION = 'SDK.InvalidSessionExpiration'
+SDK_GET_SESSION_CREDENTIAL_FAILED = 'SDK.GetSessionCredentialFailed'
+
